'use strict';

var other = require('./_virtual/other.js');

other.__exports.value = 43;

module.exports = other.__exports;
